
import numpy as np
import pdb
import matplotlib as mpl
import matplotlib.pyplot as plt
import matplotlib.dates
from datetime import datetime  

datadir = '/Users/judytwedt/Documents/ArcticCollection_2019/Data/'
np.set_printoptions(suppress=True) # suppress scientific notation
#File Names
minuteFile = datadir + 'ten_minute_in_situ_co2_mlo.txt'
dailyFile = datadir + 'daily_in_situ_co2_mlo.csv'
weeklyFile = datadir + 'weekly_in_situ_co2_mlo.csv'
monthlyFile = datadir + 'monthly_in_situ_co2_mlo.csv'
lawDomeFile = datadir + 'LawDome_CO2_2006.csv'
epicaFile = datadir + 'EpicaDomeC_co2_composite.txt'




#TODO: determine what format I want for date/time and standardize this

######################################################
# 15-minute record columns: Yr,Mn,Dy,Hr,Mi,CO2 (ppm)
######################################################
# Lot of NaN's, 1958 - 2004
###
#timespan 1958 - present
ndays = 30*60
dayfreq = 96 # number of hourly data points per day, DONT CHANGE THIS
numrows = ndays*dayfreq
minuteDataAll = np.loadtxt(minuteFile, delimiter = ',', 
				skiprows = 37, max_rows = numrows) 
minuteData = minuteDataAll[:, -1]
minuteDataDateTime = minuteDataAll[:, :5]


def getHourAvg(data):
	assert(np.mod(len(data), 4)== 0) #assure 4 data points per hour
	nhours = int(len(data)/4);
	dataReshape = np.reshape(data, [nhours, 4])
	return np.nanmean(dataReshape, axis = 1)

def getDailyAvgData(data):
	assert(np.mod(len(data), dayfreq)==0) ## assure 96 data points per day
	ndays = int(len(data)/dayfreq)
	dataReshape = np.reshape(data, [ndays, dayfreq])
	return np.nanmean(dataReshape, axis = 1)

hourlyData = getHourAvg(minuteData)
dailyData = getDailyAvgData(minuteData)



###########################################################################
# Weekly Data first column is string of dates, second column is CO2 (ppm)
###########################################################################
#timespan: 1958 = present
weeklyDataDates = np.loadtxt(weeklyFile, delimiter = ',',usecols = 0, skiprows = 44,
		 max_rows = 200, dtype = 'str')

weeklyData = np.loadtxt(weeklyFile, usecols = 1, skiprows = 44, max_rows = 200)

def convertMissingData(val):
	if val == -99.99:
		return np.nan
	else:
		 return val
#################
#Monthly Data
##################
#timesSpan:1958 - present
monthlyData = np.loadtxt(monthlyFile, usecols = 8, skiprows = 57, dtype = 'str',
			 delimiter = ',')
monthlyDataDates = np.loadtxt(monthlyFile, usecols = (3),delimiter = ',',
		 skiprows = 57)

#Format arrays
monthlyData = monthlyData.astype(float)
monthlyData = [convertMissingData(x) for x in monthlyData]
monthlyData = np.asarray(monthlyData)

###############################################################################################
#Get values for 1988, 2013
####################################### MONTHLY
def getMonthsOfYearX(year1, year2, data, dates):
	ind1 = dates < (year2 + 1)
	ind2 = dates > year1
	yearInd = ind1*ind2
	return (data[yearInd], dates[yearInd])

def getMonthDay(datestring):
	temp = [datetime.strptime(x, '%Y-%m-%j') for x in datestring]
	months = [x.month for x in temp]
	days = [y.day for y in temp]
	years = [z.year for z in temp]
	return years, months, days	
def getxPerMonth(dates):
	i = 0
	xPerMonth = np.empty([1,1])
	while (i < (len(dates) - 2)):
		counter = 1
		while dates[i] == dates[i + 1]:
			counter = counter + 1
			i = i + 1
			if i == (len(dates) -1 ):
				break
		xPerMonth = np.insert(xPerMonth, -1, np.full(counter, counter))
		i = i + 1
	return xPerMonth[:-1] # the last valus is from initialization	
		

############################################### MONTHLY
[co2_1988, dates_1988] = getMonthsOfYearX(1988,1992, monthlyData, monthlyDataDates)
[co2_2014, dates_2014] = getMonthsOfYearX(2014,2018, monthlyData, monthlyDataDates)


############################################ ANNUAL
co2Annual_1988 = np.mean(np.reshape(co2_1988, [5, 12]), axis = 1)
co2Annual_2014 = np.mean(np.reshape(co2_2014, [5,12]), axis = 1)


######################################## WEEKLY
weeks_1988 = np.loadtxt(weeklyFile, usecols = 0, skiprows = 1538,delimiter = ',', max_rows = 1 + (52*5), dtype = 'str')
co2weekly_1988 = np.loadtxt(weeklyFile, usecols = 1, skiprows = 1538,delimiter = ',',  max_rows = 1 + (52*5))
[weeklyYears1988, weeklyMons1988, weeklyDays1988] = getMonthDay(weeks_1988)


weeks_2014 = np.loadtxt(weeklyFile, usecols = 0, skiprows = 2883, max_rows = 1 + (52*5), delimiter = ',', dtype = 'str')
co2weekly_2014 = np.loadtxt(weeklyFile, usecols = 1, skiprows = 2883, delimiter = ',', max_rows = 1 + (52*5))
[weeklyYears2014, weeklyMons2014, weeklyDays2014] = getMonthDay(weeks_2014)

weeksPerMonth1988 = getxPerMonth(weeklyMons1988)
weeksPerMonth2014 = getxPerMonth(weeklyMons2014)
#pdb.set_trace()
#################################### DAILY
daysFull_1988 = np.loadtxt(dailyFile, usecols = [0,1,2], delimiter = ',', skiprows = 10991, max_rows = 1827, dtype = 'str')
days_1988 = [x[1].astype(np.int64) for x in daysFull_1988]
daysPerMonth1988 = getxPerMonth(days_1988)
co2daily_1988 = np.loadtxt(dailyFile, usecols = 3, skiprows = 10991, delimiter = ',', max_rows = 1827, dtype = 'str').astype(np.float64)

daysFull_2014 = np.loadtxt(dailyFile, usecols = [0,1,2], delimiter = ',', skiprows = 20488, max_rows = 1826, dtype = 'str')
days_2014 = [x[1].astype(np.int64) for x in daysFull_2014]
daysPerMonth2014 = getxPerMonth(days_2014)
co2daily_2014 = np.loadtxt(dailyFile, usecols = 3, delimiter = ',', skiprows = 20488, max_rows = 1826, dtype = 'str').astype(np.float64) # lots of NAN's in here! January is OK. 

####################################### 15 MINUTE, only available until 2006

minute_Jan1988 = np.loadtxt(minuteFile, delimiter = ',', usecols = [0,1,2,3,4], skiprows = 1043749, max_rows = 30*96)
co2_minute_Jan1988 = np.loadtxt(minuteFile, delimiter = ',',  usecols = [5],  skiprows = 1043749, max_rows = 30*96)
#pdb.set_trace()

###############################################################################################

###############
#lawDome
##############
#timespan: 2006 - 13 AD
#Format: year (AD), CO2 (ppm)
lawDome = np.loadtxt(lawDomeFile, skiprows = 1, delimiter = ',',
			max_rows = 250, usecols = (1,2))


#############
#Epica
#############
#timespan: 137- 798512 years BP, uneveny spaced. 
#1096 data points
#max time spacing: 6029 years, avg time spacing: 729 years
epica = np.loadtxt(epicaFile, skiprows = 11)


#pdb.set_trace()
